@@ -12,7 +12,7 @@ from selenium.webdriver.support.expected_conditions import presence_of_element_l
 class Browser(Chrome):
     root_url: str = None
     cookies_path: Path = None
-    headless: bool = False
+    headless: bool = True
     options: list = field(default_factory=list)
     experimental_options: dict = field(default_factory=dict)
     timeout: int = 10
